==> fcitx_4.2.4.1.orig.tar.xz: fcitx-4.2.4.1/src/module/xkb/xkb.h <==
/***************************************************************************
 *   Copyright (C) 2012~2012 by CSSlayer                                   *
 *   wengxt@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#ifndef FCITX_XKB_H
#define FCITX_XKB_H

#include <X11/Xlib.h>

#include "fcitx/instance.h"
#include "rules.h"

typedef struct _FcitxXkbConfig {
    FcitxGenericConfig gconfig;
    boolean bOverrideSystemXKBSettings;
    boolean bIgnoreInputMethodLayoutRequest;
} FcitxXkbConfig;

typedef struct _FcitxXkb
{
    Display* dpy;
    UT_array *defaultLayouts;
    UT_array *defaultModels;
    UT_array *defaultOptions;
    UT_array* defaultVariants;
    FcitxInstance* owner;
    int closeGroup;
    FcitxXkbRules* rules;
    FcitxXkbConfig config;
    int xkbOpcode;
    struct _LayoutOverride* layoutOverride;
} FcitxXkb;

#define FCITX_XKB_NAME "fcitx-xkb"
#define FCITX_XKB_GETRULES 0
#define FCITX_XKB_GETRULES_RETURNTYPE FcitxXkbRules*
#define FCITX_XKB_GETCURRENTLAYOUT 1
#define FCITX_XKB_GETCURRENTLAYOUT_RETURNTYPE void
#define FCITX_XKB_LAYOUTEXISTS 2
#define FCITX_XKB_LAYOUTEXISTS_RETURNTYPE void
#define FCITX_XKB_GETLAYOUTOVERRIDE 3
#define FCITX_XKB_GETLAYOUTOVERRIDE_RETURNTYPE void
#define FCITX_XKB_SETLAYOUTOVERRIDE 4
#define FCITX_XKB_SETLAYOUTOVERRIDE_RETURNTYPE void

#define FCITX_XKB_PATH "/keyboard"
#define FCITX_XKB_INTERFACE "org.fcitx.Fcitx.Keyboard"

CONFIG_BINDING_DECLARE(FcitxXkbConfig);

#endif

==> fcitx-4.2.9.8.tar.xz: fcitx-4.2.9.8/src/module/xkb/xkb.h <==
/***************************************************************************
 *   Copyright (C) 2012~2012 by CSSlayer                                   *
 *   wengxt@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************/

#ifndef FCITX_XKB_H
#define FCITX_XKB_H

#include <fcitx-utils/utarray.h>
#include <fcitx-config/fcitx-config.h>

#define FCITX_XKB_PATH "/keyboard"
#define FCITX_XKB_INTERFACE "org.fcitx.Fcitx.Keyboard"

typedef struct _FcitxXkbRules {
    UT_array* layoutInfos;
    UT_array* modelInfos;
    UT_array* optionGroupInfos;
    char* version;
} FcitxXkbRules;

typedef struct _FcitxXkbRulesHandler {
    UT_array* path;
    FcitxXkbRules* rules;
    boolean fromExtra;
} FcitxXkbRulesHandler;

typedef struct _FcitxXkbLayoutInfo {
    UT_array* variantInfos;
    char* name;
    char* description;
    UT_array* languages;
} FcitxXkbLayoutInfo;

typedef struct _FcitxXkbVariantInfo {
    char* name;
    char* description;
    UT_array* languages;
} FcitxXkbVariantInfo;

typedef struct _FcitxXkbModelInfo {
    char* name;
    char* description;
    char* vendor;
} FcitxXkbModelInfo;

typedef struct _FcitxXkbOptionGroupInfo {
    UT_array* optionInfos;
    char* name;
    char* description;
    boolean exclusive;
} FcitxXkbOptionGroupInfo;

typedef struct _FcitxXkbOptionInfo {
    char* name;
    char* description;
} FcitxXkbOptionInfo;

#endif
